delete method
Deletes this app and frees up system resources.
Once deleted, any plugin functionality using this app instance will throw an error.
Deleting the default app is not possible and throws an exception.
Implementation
Future<void> delete() async {
final registry = _registries[name];
if (registry != null) {
await Future.wait(
registry.values.map((service) {
return service.dispose().catchError((_) {});
}),
);
}
await _delegate.delete();
_registries.remove(name);
}